summaryrefslogtreecommitdiffstats
path: root/printing/metafile.h
diff options
context:
space:
mode:
Diffstat (limited to 'printing/metafile.h')
-rw-r--r--printing/metafile.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/printing/metafile.h b/printing/metafile.h
index 84c0556..dbb838c 100644
--- a/printing/metafile.h
+++ b/printing/metafile.h
@@ -53,8 +53,9 @@ class Metafile {
// This method calls StartPage and then returns an appropriate
// VectorPlatformDevice implementation bound to the context created by
// StartPage or NULL on error.
virtual SkDevice* StartPageForVectorCanvas(
+ int page_number,
const gfx::Size& page_size,
const gfx::Rect& content_area,
const float& scale_factor) = 0;
@@ -53,8 +53,9 @@ class Metafile {
// This method calls StartPage and then returns an appropriate
// VectorPlatformDevice implementation bound to the context created by
- // StartPage or NULL on error.
+ // StartPage or NULL on error. |page_number| is zero based.
virtual SkDevice* StartPageForVectorCanvas(